@@ -62,6 +62,9 @@ class Client(object):
     def fileno(self):
         return self.__stream.fileno()
 
+    def setblocking(self, block):
+        self.__stream.setblocking(block)
+
     def __create_stream(self):
         return XMLStream(self.sock, log_level=self.stream_log_level)
 
@@ -161,6 +164,9 @@ class JID(object):
         domain, resource = other.split('/', 2)
         return JID(node, domain, resource)
 
+    def get_stripped(self):
+        return '%s@%s' % (self.node, self.domain)
+
     def __str__(self):
         """
         >>> jid = JID('hello', 'example.com', 'xyz')
