@@ -1,6 +1,6 @@
 from uuid import uuid4
 from common import PlugOut
-from xmpp2.model import Node
+from xmpp2.model import XML
 import logging
 
 
@@ -15,23 +15,21 @@ class BindHandler(object):
     def get_type(self):
         return 'iq'
 
-    def get_ns(self):
-        return 'jabber:client'
-
     def get_id(self):
         return uuid4().hex
 
     def start(self):
-        node = Node('iq', type='set', id=self.get_id())
-        bind = Node('bind', xmlns=self.NS_BIND)
-        node.append(bind)
+        iq = (XML.iq(type='set', id=self.get_id())
+                .add(XML.bind(xmlns=self.NS_BIND)))
         if self.resource is not None:
-            bind.append(Node('resource', self.resource))
-        self.client.write(node)
+            iq[0].add(XML.resource.add(self.resource))
+        self.client.write(iq)
         self.client.process()
 
     def handle(self, iq):
-        jid = iq.xpath('bind:bind/bind:jid', namespaces=self.NAMESPACES)
-        if len(jid) > 0:
-            self.client._set_jid(jid[0].text)
+        try:
+            jid = iq[0][0].text
+            self.client._set_jid(jid)
+        except:
+            pass
         return PlugOut()
